@@ -1,5 +1,20 @@
 var NAVTREEINDEX17 =
 {
+"page_library.html#autotoc_md52":[5,9,3,3],
+"page_library.html#autotoc_md53":[5,9,3,4],
+"page_library.html#autotoc_md54":[5,9,3,5],
+"page_library.html#autotoc_md55":[5,9,3,6],
+"page_library.html#autotoc_md56":[5,9,3,7],
+"page_library.html#autotoc_md57":[5,9,3,8],
+"page_library.html#autotoc_md58":[5,9,3,9],
+"page_library.html#autotoc_md59":[5,9,4],
+"page_library.html#autotoc_md60":[5,9,4,0],
+"page_library.html#autotoc_md61":[5,9,4,1],
+"page_library.html#autotoc_md62":[5,9,5],
+"page_library.html#autotoc_md63":[5,9,6],
+"page_library.html#autotoc_md64":[5,9,7],
+"page_man_pipewire_1.html":[5,12,0],
+"page_man_pipewire_conf_5.html":[5,12,2],
 "page_man_pipewire_pulse_1.html":[5,12,1],
 "page_man_pw_cat_1.html":[5,12,3],
 "page_man_pw_cli_1.html":[5,12,4],
@@ -195,10 +210,10 @@ var NAVTREEINDEX17 =
 "page_tutorial5.html":[7,5],
 "page_tutorial6.html":[7,6],
 "pages.html":[],
-"spa_2examples_2adapter-control_8c-example.html":[13,24],
-"spa_2examples_2example-control_8c-example.html":[13,25],
-"spa_2examples_2local-libcamera_8c-example.html":[13,26],
-"spa_2examples_2local-v4l2_8c-example.html":[13,27],
+"spa_2examples_2adapter-control_8c-example.html":[13,25],
+"spa_2examples_2example-control_8c-example.html":[13,26],
+"spa_2examples_2local-libcamera_8c-example.html":[13,27],
+"spa_2examples_2local-v4l2_8c-example.html":[13,28],
 "structitimerspec.html":[11,0,0],
 "structpw__array.html":[10,6,0,1],
 "structpw__array.html#a3d468425a1a0084f98301e2fd9becc6b":[10,6,0,1,1],
@@ -234,20 +249,5 @@ var NAVTREEINDEX17 =
 "structpw__client__info.html#a8585e5629d10bb4359ede29782fd7c21":[10,4,3,1,0],
 "structpw__client__info.html#a9123521af948ea7b720d1ebb0f39c66b":[10,4,3,1,1],
 "structpw__client__methods.html":[10,4,3,3],
-"structpw__client__methods.html#a17155250b4b575de0530a8d01447148a":[10,4,3,3,3],
-"structpw__client__methods.html#a2804d8a526c068a486a4e261821c9a07":[10,4,3,3,5],
-"structpw__client__methods.html#a298f33a5d81477d06b08f52d233b740a":[10,4,3,3,2],
-"structpw__client__methods.html#a7af9e64e81ebc0b3a7d726ff98e0dd84":[10,4,3,3,4],
-"structpw__client__methods.html#a898d61fc799b5c09421365854020b357":[10,4,3,3,0],
-"structpw__client__methods.html#ad5cf20929a275ce91d7fdbbb80e70be3":[10,4,3,3,1],
-"structpw__client__node.html":[10,7,0,4],
-"structpw__client__node__buffer.html":[10,7,0,1],
-"structpw__client__node__buffer.html#a003e6b6549d0dbd9e2c8a6030a1cfa85":[10,7,0,1,2],
-"structpw__client__node__buffer.html#a0b4e8dbf6a9aad4e72153fd2bf5f6392":[10,7,0,1,0],
-"structpw__client__node__buffer.html#a1d524a38ed82fb88371d741bcb1e3ff0":[10,7,0,1,1],
-"structpw__client__node__buffer.html#a27039caf89b376d354a33d1559e939b3":[10,7,0,1,3],
-"structpw__client__node__events.html":[10,7,0,2],
-"structpw__client__node__events.html#a0942c754a0fd77db7c9051172b2ac991":[10,7,0,2,10],
-"structpw__client__node__events.html#a0fdb140f41117e7690aca449844d72c2":[10,7,0,2,9],
-"structpw__client__node__events.html#a3802ec24f1305664c8d1b846abc244c8":[10,7,0,2,7]
+"structpw__client__methods.html#a17155250b4b575de0530a8d01447148a":[10,4,3,3,3]
 };
